#
# spec file for package snpguest
#
# Copyright (c) 2024 SUSE LLC
# Copyright (C) 2023 VirTEE
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           snpguest
VCS: https://src.suse.de/SLFO-pool/snpguest#e4c134dc1a8b35f22ff301c3b7820506aa31d0c3b31a8b5912a34be7f2583071
Version:        0.7.1
Release:        160000.1.11
Summary:        A Rust command-line tool for interacting with the AMD Secure Processor
License:        Apache-2.0
Group:          Productivity/Security
URL:            https://github.com/virtee/snpguest
Source0:        %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  cargo
BuildRequires:  cargo-packaging
ExclusiveArch:  x86_64

%description
snpguest is a command line utility for interacting with the AMD Secure Encrypted Virtualization - Secure Nested Paging (SEV-SNP) guest environment (via the /dev/sev-guest device).

%prep
# The number passed to -a (a stands for "after") should be equivalent to the Source tag number
# of the vendor tarball, 1 in this case (from Source1).
%autosetup -a1

%build
%{cargo_build}

%install
%{cargo_install}

%check
%{cargo_test}

%files
%license LICENSE
%doc README.md
%{_bindir}/%{name}

%changelog
* Thu Oct  3 2024 caleb.crane@suse.com
- Spec: Add direct dependency on cargo in addition to cargo-packaging.
    This fixes build errors on 15SP7 where the inherited version of Rust
    is too old
* Fri Sep 13 2024 Caleb Crane (caleb.crane@suse.com)
- Update to version 0.7.1:
  * Fixing clippy version bug
  * Fixing case sensitivity bug
  * Reflect 0.7.0 update in Cargo.lock
  * Update to 0.7.0
  * README: Clarify fetch ca documentation
  * Upgrade MSRV to 1.80
  * Upgrade MSRV to 1.74
  * Remove strict versioning on clap dependency
  * Update the README.md: fix the uncomplete description of the fetch ca command.
  * Added build dependencies for openSUSE (#64)
* Mon Aug 12 2024 Caleb Crane (caleb.crane@suse.com)
- Service: Remove deprecated cargo_config and cargo_audit services, both
    are now handled by the cargo_vendor service
- Spec: Remove pre-release tag from version string
- Fix build failure after update to Rust 1.80 (bsc#1228972)
- Update to version 0.6.0:
  * bumping version
  * Adding preattestation functionality to snpguest (#63)
  * rust: Patching for latest rust update
  * Update to 0.5.1
  * Update to 0.5.0
  * fix: remove subcommand trait on ok command
  * clap-migration: Moving from StructOpt to Clap
  * Fix the context message for failing to open SEV firmware.
  * Adding SNPHOST workflows to SNPGUEST
  * Additional Features
  * Adding snpguest ok
  * vlek: Missing some logic during verify for vlek.
  * Bump mio from 0.8.10 to 0.8.11
  * URL: Fixing URL breakage
  * Fix typo in verify_attestation() function
  * Bumping required Rust version to 1.70
  * VLEK: Adding ASVK Support
  * hyperv: Missing closure for boolean state.
  * Fetch: Adding status check to HTTP response
  * VLEK: Adding VLEK support to tooling
  * fetch: Adding Siena and Bergamo support
  * Adding DCO and auto-assign
  * Update README.md
  * Dependencies: Updating Cargo.toml
  * Update Readme
  * CI test1- Create rust.yml
  * cert: Fixing minor bug with certificates
  * Updating README.md
  * Adding Extended and Regular Attestation Flowcharts
  * Fixing report request serialization
  * hyperv: Adding feature flag for hyperv
  * VCEK: Patching for x509 error
  * 9: Adding Cargo.lock for dependency tracking
  * 9: Adding Rust Minimum Version
  * Auto Assign: Adding yml files
* Mon Jan 22 2024 Caleb Crane (caleb.crane@suse.com)
- Update to version 0.3.2~0:
  * crates.io: Updating crates.io for publishing
  * cert: Fixing minor bug with certificates
  * Fixing report request serialization
  * hyperv: Adding feature flag for hyperv
  * VCEK: Patching for x509 error
  * 9: Adding Cargo.lock for dependency tracking
  * 9: Adding Rust Minimum Version
  * Auto Assign: Adding yml files
  * Update docs/snpguest.1.adoc
  * Change false to hv in main
  * Fixing comments on PR, added code to main, and fixed flag ambiguity
  * Adding Derived Key Feature
  * azure: Use mutable variable instead of consistently recreating
  * docs: Document report --platform flag
  * report: Add --platform flag for Hyper-V
  * hyperv: Require VMPL 0 for attestation report
  * hyperv: Check for hypervisor guest + Hyper-V functions
  * hyperv: Fetch attestation report from Azure vTPM
  * hyperv: Detect if in a Hyper-V SEV-SNP guest
  * Reformat with cargo fmt
  * verify: Fix clippy warning
  * Fixing clippy Errors
  * Changed Attestation workflow to always require a bin Attestation Report. Fixed requested changes.
  * Adding new write_cert function. Organizing code.
  * Adding proctype enum
  * Attestation Report requested when used. New fetch command. Continuity fixes.
  * Fixing dependencies
* Mon Jul 10 2023 larry.j.dewey@gmail.com
- Update to version 0.2.2~0:
  * Update to 0.2.2
  * Update Cargo.toml readme field
  * Update to 0.2.1
* Tue Jun  6 2023 larry.j.dewey@gmail.com
- Update to version 0.2.0~0:
  * Fixing dependencies
  * Changed VMPL to use updated SEV library
  * Convert README to Markdown
  * .gitignore: Add Cargo.lock
  * Reformat
  * Made certificate path and proc model required. Changed Cargo.toml. Shortened verify  commands.
  * Restrucuted project. Using updated SEV library. Adressed comments.
  * Changed identification to enum
  * Fixed request module with comments. Now using new virtee library
  * Added verify-TCB, attestation signture verification and quiet flag
* Tue Jun  6 2023 larry.j.dewey@gmail.com
- Update to version 0.2.0~0:
  * Fixing dependencies
  * Changed VMPL to use updated SEV library
  * Convert README to Markdown
  * .gitignore: Add Cargo.lock
  * Reformat
  * Made certificate path and proc model required. Changed Cargo.toml. Shortened verify  commands.
  * Restrucuted project. Using updated SEV library. Adressed comments.
  * Changed identification to enum
  * Fixed request module with comments. Now using new virtee library
  * Added verify-TCB, attestation signture verification and quiet flag
* Tue May 23 2023 larry.j.dewey@gmail.com
- Initial Release v0.2.0
